import sys
import inspect

from .utils import read_config
from .exceptions import UnsupportedObject


class Exconsts(object):
    """Main class
    """

    def __init__(self, filename=None):
        if filename:
            self._config = read_config(filename)

    @staticmethod
    def _const_style(var):
        var = str(var).replace(' ', '_').replace('-', '_')
        return var.upper()

    def create_consts(self, obj, is_module=False):
        """Create consts in scope of the obj.

        :param obj: Object. Must be class or module.
        :param is_module: When you set consts for module
        :return: None
        """
        if inspect.isclass(obj):
            for var, value in self._config.items():
                setattr(obj, self._const_style(var), value)

        elif is_module:
            for var, value in self._config.items():
                var = self._const_style(var)
                setattr(sys.modules[obj], self._const_style(var), value)

        else:
            raise UnsupportedObject("obj must be class or module")
